@@ -6,7 +6,7 @@ use FCGI::Engine::Manager::Server;
 
 use Config::Any;
 
-our $VERSION   = '0.09'; 
+our $VERSION   = '0.10';
 our $AUTHORITY = 'cpan:STEVAN';
 
 with 'MooseX::Getopt';
@@ -25,11 +25,11 @@ has '_config' => (
     default  => sub {
         my $self   = shift;
         my $file   = $self->conf->stringify;
-        my $config = Config::Any->load_files({ 
+        my $config = Config::Any->load_files({
             files   => [ $file ],
             use_ext => 1
         })->[0]->{$file};
-        #use Data::Dumper; 
+        #use Data::Dumper;
         #warn Dumper $config;
         return $config;
     }
@@ -41,12 +41,12 @@ has '_servers' => (
     lazy      => 1,
     default   => sub {
         my $self = shift;
-        return [ 
-            map { 
+        return [
+            map {
                 $_->{server_class} ||= "FCGI::Engine::Manager::Server";
                 Class::MOP::load_class($_->{server_class});
                 $_->{server_class}->new(%$_);
-            } @{$self->_config} 
+            } @{$self->_config}
         ];
     },
 );
@@ -55,39 +55,39 @@ sub log { shift; print @_, "\n" }
 
 sub start {
     my $self = shift;
-    
+
     local $| = 1;
-    
+
     $self->log("Starting up the FCGI servers ...");
 
     my @servers = (@_ && defined $_[0]) ? $self->_find_server_by_name( @_ ) : @{ $self->servers };
 
     foreach my $server ( @servers ) {
-    
+
         if (-e $server->pidfile) {
             my $pid = $server->pid_obj;
             if ($pid->is_running) {
                 $self->log("Pid " . $pid->pid . " is already running");
                 return;
             }
-            $server->remove_pid_object;
+            $server->remove_pid_obj;
         }
-    
+
         my @cli = $server->construct_command_line();
         $self->log("Running @cli");
-    
+
         unless (system(@cli) == 0) {
             $self->log("Could not execute command (@cli) exited with status $?");
             return;
         }
-    
+
         my $count = 1;
         until (-e $server->pidfile) {
             $self->log("pidfile (" . $server->pidfile . ") does not exist yet ... (trying $count times)");
             sleep 2;
             $count++;
         }
-        
+
         my $pid = $server->pid_obj;
 
         while (!$pid->is_running) {
@@ -96,7 +96,7 @@ sub start {
         }
 
         $self->log("Pid " . $pid->pid . " is running");
-    
+
     }
 
     $self->log("... FCGI servers have been started");
@@ -104,59 +104,59 @@ sub start {
 
 sub status {
     my $self = shift;
-    
+
     my @servers = (@_ && defined $_[0]) ? $self->_find_server_by_name( @_ ) : @{ $self->servers };
-    
+
     my $status = '';
     foreach my $server ( @servers ) {
-    
+
         $status .= $server->name;
-    
+
         if (! -f $server->pidfile ) {
             $status .= " is not running\n";
             next;
         }
-    
+
         my $pid = $server->pid_obj;
-    
+
         $status .= $pid->is_running ? " is running\n" : " is not running\n"
     }
-    
-    return $status;    
+
+    return $status;
 }
 
 sub stop {
     my $self = shift;
-    
-    local $| = 1;    
-        
+
+    local $| = 1;
+
     $self->log("Killing the FCGI servers ...");
 
     my @servers = (@_ && defined $_[0]) ? $self->_find_server_by_name( @_ ) : @{ $self->servers };
 
     foreach my $server ( @servers ) {
-    
+
         if (-f $server->pidfile) {
-            
+
             my $pid = $server->pid_obj;
-            
+
             $self->log("Killing PID " . $pid->pid . " from $$ ");
             kill TERM => $pid->pid;
 
             while ($pid->is_running) {
                 $self->log("pid (" . $server->pidfile . ") is still running, sleeping ...");
                 sleep 1;
-            } 
-            
-            $server->pid_obj->remove();
+            }
+
+            $server->pid_obj->remove;
             $server->remove_pid_obj;
         }
-    
+
         if (-e $server->socket) {
             unlink($server->socket);
         }
-    
-    }    
+
+    }
 
     $self->log("... FCGI servers have been killed");
 }
@@ -176,7 +176,7 @@ sub graceful {
     foreach my $server ( @servers ) {
         push @pids, $server->pid_obj->pid;
         unlink($server->pidfile);
-        $server->remove_pid_obj();
+        $server->remove_pid_obj;
     }
     $self->start( @_ );
     foreach my $pid ( @pids ) {
@@ -188,7 +188,7 @@ sub graceful {
             $self->log("pid (" . $server->pidfile . ") has not been removed, sleeping ...");
             sleep 1;
         }
-        $server->pid_obj->write();
+        $server->pid_obj->write;
     }
 }
 
@@ -219,44 +219,44 @@ FCGI::Engine::Manager - Manage multiple FCGI::Engine instances
   my $m = FCGI::Engine::Manager->new(
       conf => 'conf/my_app_conf.yml'
   );
-  
+
   my ($command, $server_name) = @ARGV;
-  
+
   $m->start($server_name)        if $command eq 'start';
-  $m->stop($server_name)         if $command eq 'stop';  
+  $m->stop($server_name)         if $command eq 'stop';
   $m->restart($server_name)      if $command eq 'restart';
   $m->graceful($server_name)      if $command eq 'graceful';
-  print $m->status($server_name) if $command eq 'status';     
+  print $m->status($server_name) if $command eq 'status';
 
   # on the command line
-  
+
   perl all_my_fcgi_backends.pl start
   perl all_my_fcgi_backends.pl stop
-  perl all_my_fcgi_backends.pl restart foo.server  
-  # etc ...  
+  perl all_my_fcgi_backends.pl restart foo.server
+  # etc ...
 
 =head1 DESCRIPTION
 
-This module handles multiple L<FCGI::Engine> instances for you, it can 
-start, stop and provide basic status info. It is configurable using 
-L<Config::Any>, but only really the YAML format has been tested. 
+This module handles multiple L<FCGI::Engine> instances for you, it can
+start, stop and provide basic status info. It is configurable using
+L<Config::Any>, but only really the YAML format has been tested.
 
 This module is still in it's early stages, many things may change.
 
 =head2 Use with Catalyst
 
-Since L<FCGI::Engine> is pretty much compatible with 
-L<Catalyst::Engine::FastCGI>, this module can also be used to manage 
-your L<Catalyst::Engine::FastCGI> based apps as well as your 
+Since L<FCGI::Engine> is pretty much compatible with
+L<Catalyst::Engine::FastCGI>, this module can also be used to manage
+your L<Catalyst::Engine::FastCGI> based apps as well as your
 L<FCGI::Engine> based apps.
 
 =head1 EXAMPLE CONFIGURATION
 
-Here is an example configuration in YAML, it should be noted that 
-the options for each server are basically the constructor params to 
-L<FCGI::Engine::Manager::Server> and are passed verbatim to it. 
-This means that if you subclass L<FCGI::Engine::Manager::Server> 
-and set the C<server_class:> option appropriately, it should pass 
+Here is an example configuration in YAML, it should be noted that
+the options for each server are basically the constructor params to
+L<FCGI::Engine::Manager::Server> and are passed verbatim to it.
+This means that if you subclass L<FCGI::Engine::Manager::Server>
+and set the C<server_class:> option appropriately, it should pass
 any new options you added to your subclass automatically.
 
   ---
@@ -265,7 +265,7 @@ any new options you added to your subclass automatically.
     scriptname:      "t/scripts/foo.pl"
     nproc:            1
     pidfile:         "/tmp/foo.pid"
-    socket:          "/tmp/foo.socket" 
+    socket:          "/tmp/foo.socket"
     additional_args: [ "-I", "lib/" ]
   - name:       "bar.server"
     scriptname: "t/scripts/bar.pl"
